#' banditpam is a package for fast clustering using medoids
#'
#' @description banditpam is a high-performance package for almost
#'   linear-time k-medoids clustering. The methods are described in
#'   Tiwari, et al. 2020 (Advances in Neural Information Processing Systems
#'   33).
#'
#' @name banditpam-package
#' @useDynLib banditpam
#' @author Balasubramanian Narasimhan and Mo Tiwari
#' @keywords package
"_PACKAGE"

catn <- function(...) cat(..., "\n")
